import QtQuick
import QtQuick.Controls

import Artix.Gui

/**
 * @brief Всплывающая клавиатура
 * @param hidedY значение y в скрытом состоянии
 * @param shownY значение y в отображенном состоянии
 */
Popup {
    id: control
    required property real hidedY
    required property real shownY
    property InlineKeyboard keyboard: keyboard

    parent: Overlay.overlay
    x: 0
    y: hidedY
    width: parent.width
    height: parent.height * 0.536
    topPadding: 16
    bottomPadding: 24
    closePolicy: Popup.NoAutoClose
    contentItem: Item {
        InlineKeyboard {
            id: keyboard
            anchors.horizontalCenter: parent.horizontalCenter
            height: parent.height
            width: height * sizeRatio
            property real sizeRatio: {
                if (["dialpad", "digits", "numbers", "input_digits"].indexOf(layoutType) !== -1)
                    return 0.86487;
                return 2.58065
            }
            layoutType: "main"
        }
    }
    background: Rectangle {
        color: Style.parameter("color.modalBackground")
        // Тень
        Rectangle {
            anchors.bottom: parent.top
            width: parent.width
            height: 5
            visible: control.opened
            gradient: Gradient {
                orientation: Gradient.Vertical
                GradientStop { position: 0.0; color: "transparent" }
                GradientStop { position: 1.0; color: Style.parameter("color.shadow") }
            }
            opacity: 0.3
        }
    }
    enter: Transition { SmoothedAnimation { velocity: 2000; property: "y"; to: shownY } }
    exit: Transition { SmoothedAnimation { velocity: 2000; property: "y"; to: hidedY } }
}
